scope_effect

Function scope_effect 

pub fn scope_effect(name: &Token, data: &Everything) -> Option<(Scopes, Effect)>
Look up an effect name token in the effects table. name is the token. data is used in special cases to verify the name dynamically.